/* GCC */
#include <cstdio>
#include <algorithm>

#define abs(x) ((x) > 0 ? (x) : -(x))

using namespace std;

const int nMax = 2500;

struct Point
{
    int x, y;
    int ind, color;
    Point () {}
    Point (int x, int y)
    {
        this->x = x;
        this->y =y;
    }

    Point operator - (const Point& p) const
    {
        return Point (x - p.x, y - p.y);
    }

    bool operator < (const Point& p) const
    {
        return (x < p.x) || (x == p.x && y < p.y);
    }

    int operator * (const Point& p) const
    {
        return x*p.y - p.x*y;
    }
};

Point points[2*nMax];

struct Compare
{
    Point c;
    Compare (const Point& c)
    {
        this->c =c;
    }
    bool operator () (const Point& p1, const Point& p2) const
    {
        return (p1-c)*(p2-c) > 0;
    }
};

inline void write (const Point& p1, const Point& p2)
{
    if (p1.color == 1)
        printf ("%d %d\n", p1.ind, p2.ind);
    else
        printf ("%d %d\n", p2.ind, p1.ind);
}

void solve (int b, int e)
{
    int best = b;
    if (b >= e)
        return;
    for (int i = b; i < e; i++)
        if ( points[i] < points[best] )
            best = i;
    swap (points[b], points[best]);
    sort (points + b + 1, points + e, Compare (points[b]));
    int sum = 0, divp = 10*nMax;
    for (int i = b+1; i < e; i++)
    {
        if (sum == 0 && points[b].color != points[i].color)
        {
            if ( abs(divp-(b + e)/2) > abs(i-(b + e)/2) )
                divp = i;
        }
        sum += points[i].color;
    }
    write (points[b], points[divp]);

    solve (b + 1, divp);
    solve (divp + 1, e);
}

int main ()
{
    freopen ("pairs.in", "r", stdin);
    freopen ("pairs.out", "w", stdout);

    int n, i, tests;

    for ( scanf ("%d", &tests); tests; --tests )
    {
        scanf ("%d", &n);
        for (int i = 0; i < n; i++)
        {
            scanf ("%d %d", &points[i].x, &points[i].y);
            points[i].color = 1;
            points[i].ind = i+1;
        }
        for (int i = 0; i < n; i++)
        {
            scanf ("%d %d", &points[i + n].x, &points[i + n].y);
            points[i + n].color = -1;
            points[i + n].ind = i + 1;
        }
        solve (0, 2*n);
    }

    return 0;
}
