/* GCC */
#include <cstdio>
#include <cmath>
#include <set>
#include <vector>
#include <algorithm>

using namespace std;

const float pi = acos(-1.0f);
int T, N;

struct point {
    int x, y, index;
    bool color;
    inline float pol_ang() const {
        if(x == 0) {
            return y >= 0 ? pi/2 : -pi/2;
        }
        if(x > 0) {
            return atan(float(y)/x);
        }
        return pi + atan(float(y)/x);
    }
    inline bool operator < (point pt) const {
        float pa1 = pol_ang(), pa2 = pt.pol_ang();
        if(pa1 == pa2) {
            return sqrt(x*x + y*y) > sqrt(pt.x*pt.x + pt.y*pt.y);
        }
        return pa1 < pa2;
    }
    inline bool operator == (point pt) const {
        return x == pt.x && y == pt.y;
    }
};

vector< vector<point> > v_pts;
vector< set<point> > pts;

inline bool compX(const point &p1, const point &p2) {
    return p1.x < p2.x;
}

inline void split_pts(int k) {
    int cntt = 0, cntf = 0;
    for(int i = v_pts[k].size() - 1; i > 0; i--) {
        if(v_pts[k][i].color)
            cntt++;
        else
            cntf++;

        if(cntt == cntf) {
            v_pts.push_back(vector<point>(v_pts[k].begin() + i, v_pts[k].end()));
            v_pts[k].resize(i);
            pts[k] = set<point>(v_pts[k].begin(), v_pts[k].end());
            pts.push_back(set<point>(v_pts.back().begin(), v_pts.back().end()));
            return;
        }
    }
}

vector<point> hull;

inline bool left_corn(const point &a, const point &b, const point &c) {
    long ux = c.x - b.x, uy = c.y - b.y;
    long vx = b.x - a.x, vy = b.y - a.y;
    bool res = ux*vy > vx*uy;
    return res;
}

inline void graham_scan(int vi) {
    hull.clear();

    if(pts[vi].size() < 3) {
        hull = vector<point>(pts[vi].begin(), pts[vi].end());
        return;
    }

    set<point>::iterator it = pts[vi].begin();
    hull.push_back(*it++);
    hull.push_back(*it++);
    for(; it != pts[vi].end(); ++it) {
        while(hull.size() > 1 && !left_corn(hull[hull.size()-2], hull[hull.size()-1], *it)) {
            hull.pop_back();
        }
        hull.push_back(*it);
    }
}

int main() {
    freopen("pairs.in", "r", stdin);
    freopen("pairs.out", "w", stdout);

    scanf("%d", &T);

    for(int x, y; T--;) {
        v_pts.clear(); v_pts.push_back(vector<point>());
        pts.clear(); pts.push_back(set<point>());

        scanf("%d", &N);

        v_pts[0].resize(2*N);

        for(int i = 0; i < N; i++) {
            scanf("%d%d", &v_pts[0][i].x, &v_pts[0][i].y);
            v_pts[0][i].index = i+1;
            v_pts[0][i].color = 0;
            pts[0].insert(v_pts[0][i]);
        }

        for(int i = 0; i < N; i++) {
            scanf("%d%d", &v_pts[0][N+i].x, &v_pts[0][N+i].y);
            v_pts[0][N+i].index = i+1;
            v_pts[0][N+i].color = 1;
            pts[0].insert(v_pts[0][N+i]);
        }

        sort(v_pts[0].begin(), v_pts[0].end(), compX);

        for(int k = 0; k < pts.size(); k++) {
            do {
                graham_scan(k);

                bool flag = true;
                for(int i = 1; i <= hull.size(); i++) {
                    if(hull[i%hull.size()].color == !hull[i-1].color) {
                        if(!hull[i].color) {
                             printf("%d %d\n", hull[i%hull.size()].index, hull[i-1].index);
                        } else {
                             printf("%d %d\n", hull[i-1].index, hull[i%hull.size()].index);
                        }
                        pts[k].erase(hull[i%hull.size()]); pts[k].erase(hull[i-1]);
                        v_pts[k].erase(find(v_pts[k].begin(), v_pts[k].end(), hull[i%hull.size()]));
                        v_pts[k].erase(find(v_pts[k].begin(), v_pts[k].end(), hull[i-1]));
                        i++;
                        flag = false;
                    }
                }

                if(flag) {
                    split_pts(k);
                }
            } while(!pts[k].empty());
        }
    }

    return 0;
}
